@@ -4,6 +4,7 @@
 from __future__ import print_function
 import json
 
+
 def _pretty(data, pretty):
     """return output in pretty print"""
     if pretty:
@@ -39,17 +40,16 @@ def _search(data, search, default):
 
 def _findval(data, path, pathsep, ignorecase):
     """cycle through Dict and find the key's value"""
-    if r'\.' in path:
+    if r"\." in path:
         path = path.replace(r"\.", "__dictor__")
- 
-    for key in path.split(pathsep):
-        if '__dictor__' in key:
-            key = key.replace('__dictor__', '.')
 
+    for key in path.split(pathsep):
+        if "__dictor__" in key:
+            key = key.replace("__dictor__", ".")
         if isinstance(data, (list, tuple)):
             try:
                 val = data[int(key)]
-            except IndexError:
+            except (UnboundLocalError, IndexError, ValueError):
                 val = None
         else:
             if ignorecase:
@@ -57,9 +57,6 @@ def _findval(data, path, pathsep, ignorecase):
                     if datakey.lower() == key.lower():
                         key = datakey
                         break
-            
-
-
             try:
                 if data and key in data:
                     val = data[key]
@@ -136,9 +133,11 @@ def dictor(
     if all([search is None, path is None]):
         return _pretty(data, pretty)
 
+    val = None
+
     if path:
         val = _findval(data, path, pathsep, ignorecase)
-    if search and path:
+    if search and path and val:
         val = _search(val, search, default)
     if search and not path:
         val = _search(data, search, default)
@@ -153,8 +152,10 @@ def dictor(
     # return specific type
     if rtype and (type(val) is str or type(val) is int):
         try:
-            if rtype == "int": val = int(val)
-            if rtype == "str": val = str(val)
+            if rtype == "int":
+                val = int(val)
+            if rtype == "str":
+                val = str(val)
         except ValueError:
-            pass       
-    return _pretty(val, pretty)
\ No newline at end of file
+            pass
+    return _pretty(val, pretty)
